# Mercury
Mercury is a batteries included framework like Django, but with the simplicity of Flask. It allows
you to build web API's in a fast timely manner. The project uses the already existing Werkzeug
wrappers for a similar and efficient field when developing.

# Features
 - Dynamic routing
 - ORM with custom migration system
 - Custom validation API that handles bad requests for you
 - Custom JWT token system
 - Inovative autogeneration system that writes commonly used API's for you
